@@ -3,9 +3,9 @@ package com.sun.tools.javac.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "15.0.2+7-27" },
-            { "jdk", "15.0.2" },
-            { "release", "15.0.2" },
+            { "full", "17.0.8+7" },
+            { "jdk", "17.0.8" },
+            { "release", "17.0.8" },
         };
     }
 }
